Index: src/uk/me/parabola/imgfmt/app/net/RoadNetwork.java
===================================================================
--- src/uk/me/parabola/imgfmt/app/net/RoadNetwork.java	(revision 4303)
+++ src/uk/me/parabola/imgfmt/app/net/RoadNetwork.java	(working copy)
@@ -260,6 +260,7 @@
 	public List<RouteCenter> getCenters() {
 		if (centers.isEmpty()){
 			angleChecker.check(nodes);
+			findRoutingIslands();
 			addArcsToMajorRoads();
 			splitCenters();
 		}
@@ -266,6 +267,20 @@
 		return centers;
 	}
 
+	private void findRoutingIslands() {
+		final int visitId = 1;
+		
+		List<RouteNode> nodesToVisit = new ArrayList<>(nodes.values());
+		
+		while (!nodesToVisit.isEmpty()) {
+			List<RouteNode> connected = new ArrayList<>();
+			nodesToVisit.iterator().next().visitNet(visitId, connected);
+			if (connected.size() < 5 && connected.stream().noneMatch(RouteNode::isBoundary))
+				log.warn("routing island with only", connected.size(), "routing node(s) at", connected.get(0).getCoord().toDegreeString());
+			nodesToVisit.removeIf(n -> n.getVisitID() == visitId);
+		}
+	}
+
 	/**
 	 * add indirect arcs for each road class (in descending order)
 	 */
Index: src/uk/me/parabola/imgfmt/app/net/RouteNode.java
===================================================================
--- src/uk/me/parabola/imgfmt/app/net/RouteNode.java	(revision 4303)
+++ src/uk/me/parabola/imgfmt/app/net/RouteNode.java	(working copy)
@@ -929,5 +929,21 @@
 		return result;
 	}
 
+	/** used to find routing island, but may also be used for other checks */
+	private int visitID;
 	
+	public int getVisitID() {
+		return visitID;
+	}
+
+	public void visitNet(int visitId, List<RouteNode> visited) {
+		if (this.visitID == visitId)
+			return;
+		visited.add(this);
+		this.visitID = visitId;
+		for (RouteArc arc : arcs) {
+			arc.getDest().visitNet(visitId, visited);
+		}
+	}
+	
 }
